.. GRIDOPT documentation master file, created by
   sphinx-quickstart on Wed Jan  6 17:47:23 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

GRIDOPT Documentation
=====================

Welcome! This is the documentation for GRIDOPT version |version|, last updated |today|.

**What is GRIDOPT?**

GRIDOPT is a Python package that provides methods for solving power grid optimization problems.

**License**

GRIDOPT is released under the BSD 2-clause license.

**Contents**

.. module:: gridopt

.. toctree::
   :numbered:
   :maxdepth: 3

   Getting Started<start>
   Power Flow Methods<power_flow>
   Command-Line Utility<script>	      
   API Reference<reference>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

